@@ -1171,3 +1171,21 @@ class APIVisitor(APIParserVisitor):
             errorMsg = ctx.exception.message
 
         return originScript, errorCode, errorMsg
+
+    def visitHelp(self, ctx: APIParser.HelpContext):
+        parsedObject = {'name': 'HELP'}
+
+        parsedObject.update({'topic': ""})
+        if ctx.HELP_COMMAND() is not None:
+            parsedObject.update({'topic': str(ctx.HELP_COMMAND().getText()).strip().upper()})
+
+        # 获取错误代码
+        errorCode = 0
+        errorMsg = None
+        if ctx.exception is not None:
+            errorCode = -1
+            errorMsg = ctx.exception.message
+
+        self.parsedObject = parsedObject
+        self.errorCode = errorCode
+        self.errorMsg = errorMsg
